==> anarchism_15.0.orig.tar.gz: afaq-15.0/markdown/quotes.md <==
  

What Anarchists Say about An Anarchist FAQ  
  

# What Anarchists Say about An Anarchist FAQ

_"At long last An Anarchist Frequently Asked Questions (AFAQ)  
has moved from the Internet onto the printed page . . . it is  
likely to be the primary source anarchists turn too for  
information about anarchist theory and history . . . . It is  
accessible, not laden with jargon but also built on ten years  
and more of solid research . . . The structure of the book is  
such that it is easy to dip into . . . this [is a] comprehensive  
resource. The prefix to the book is '_An'_ Anarchist FAQ. The  
collective is too modest. This is _the_ place to go to find  
out about anarchist ides, theory and practice. It is accessible  
and based on sound research. Thoroughly recommended."_  
([Richard Griffin, **Freedom**](http://anarchism.pageabode.com/afaq/freedom-
review-of-an-anarchist-faq)).

_"the primary source of information about anarchism on the  
world wide web . . . a foundation stone for laying down the idea  
of anarchism as the viable alternative that we should work towards  
achieving."_ (_"Workers Solidarity"_, **Workers Solidarity  
Movement**)

_"this invaluable resource is highly recommended for anyone  
wishing to delve further or gain a better understanding of anarchism  
as a practice, living, socially relevant ideology."_  
(_"Direct Action"_, **Solidarity Federation**)

_"The anarchist FAQ has been one of the standout achievements of  
the last decade in terms of its rigorous treatment of every aspect of  
the theory. Its translation from screen to print is long overdue."_  
(**Freedom**)

_"the most comprehensive resource available . . . for a discussion  
on anarchism is An Anarchist FAQ"_ (Flint Jones, **NEFAC**)

_"The Anarchist FAQ collective are to be congratulated on producing  
this excellent book. Always intended to be used by anarchists as an  
organising tool, the FAQ will also be useful to newcomers to anarchism  
and to those who already think of themselves as anarchists, but who would  
like to deepen their understanding of anarchist politics. The FAQ format  
makes it really easy to dip into in order to find answers to all those  
questions that anarchists are often asked by sceptics and critics (of  
right and left) as well as by other activists who are sympathetic but  
just don't know much about anarchism, or have been influenced by the  
many misrepresentations of anarchism put about by Leninists and the  
capitalist media. So The Anarchist FAQ succeeds in being a very  
accessible introduction to anarchism, whilst being at the same time  
detailed, wide-ranging, properly researched and authoritative. Highly  
recommended!"_ (David Berry author of **A History of the French  
Anarchist Movement, 1917-1945**)

_"Thanks for a fabulous job on this. What an amazing project! . . . All  
best wishes to all of you, and again, congratulations on a excellent work."_  
(Mark Leier, author of **Bakunin: The Creative Passion**)

_"monumental and essential FAQ dedicated to anarchism"_  
(Norman Baillargeon, **L'order moins le pouvoir: Histoire et  
actualité de l'anarchisme**)

_"The Anarchist FAQ should be one of the first stops for anyone  
studying anarchism. It's an extensive compilation of material,  
painstakingly indexed, of anarchist history, theory and practice.  
Just tracing the tantalising block quotes to their original sources,  
via the amazing bibliography--which alone is worth the price of the  
book--will take you a long way toward an education on any of the  
subject headings. On a personal note, I benefited greatly from  
stumbling across the FAQ near the beginning of my own journey  
into anarchism." _ (Kevin Carson author of **Studies in  
Mutualist Political Economy**)

_""Found it very detailed and informative and I'm sure it will prove to be an  
excellent reference book for those interested in the subject and for those  
who wish to defend anarchism."_ (John Couzin, anarchist from Glasgow)

  

[‹ An Anarchist FAQ: Introduction to Volume 2](/afaq/vol2intro.html "Go to
previous page" ) [up](/afaq/intro.html "Go to parent page" ) [An Anarchist FAQ
Webpage Contacts ›](/afaq/contact.html "Go to next page" )

==> anarchism_15.3.orig.tar.gz: afaq-15.3/markdown/quotes.md <==
  

What Anarchists Say about An Anarchist FAQ  
  

# What Anarchists Say about An Anarchist FAQ

_"At long last An Anarchist Frequently Asked Questions (AFAQ)  
has moved from the Internet onto the printed page . . . it is  
likely to be the primary source anarchists turn too for  
information about anarchist theory and history . . . . It is  
accessible, not laden with jargon but also built on ten years  
and more of solid research . . . The structure of the book is  
such that it is easy to dip into . . . this [is a] comprehensive  
resource. The prefix to the book is ' _An'_ Anarchist FAQ. The  
collective is too modest. This is _the_ place to go to find  
out about anarchist ides, theory and practice. It is accessible  
and based on sound research. Thoroughly recommended."_  
([Richard Griffin, **Freedom**](freedom-review-of-an-anarchist-faq)).

_"the primary source of information about anarchism on the  
world wide web . . . a foundation stone for laying down the idea  
of anarchism as the viable alternative that we should work towards  
achieving."_ ( _"Workers Solidarity"_ , **Workers Solidarity  
Movement**)

_"this invaluable resource is highly recommended for anyone  
wishing to delve further or gain a better understanding of anarchism  
as a practice, living, socially relevant ideology."_  
( _"Direct Action"_ , **Solidarity Federation** )

_"The anarchist FAQ has been one of the standout achievements of  
the last decade in terms of its rigorous treatment of every aspect of  
the theory. Its translation from screen to print is long overdue."_  
( **Freedom** )

_"the most comprehensive resource available . . . for a discussion  
on anarchism is An Anarchist FAQ"_ (Flint Jones, **NEFAC** )

_"The Anarchist FAQ collective are to be congratulated on producing  
this excellent book. Always intended to be used by anarchists as an  
organising tool, the FAQ will also be useful to newcomers to anarchism  
and to those who already think of themselves as anarchists, but who would  
like to deepen their understanding of anarchist politics. The FAQ format  
makes it really easy to dip into in order to find answers to all those  
questions that anarchists are often asked by sceptics and critics (of  
right and left) as well as by other activists who are sympathetic but  
just don't know much about anarchism, or have been influenced by the  
many misrepresentations of anarchism put about by Leninists and the  
capitalist media. So The Anarchist FAQ succeeds in being a very  
accessible introduction to anarchism, whilst being at the same time  
detailed, wide-ranging, properly researched and authoritative. Highly  
recommended!"_ (David Berry author of **A History of the French  
Anarchist Movement, 1917-1945**)

_"Thanks for a fabulous job on this. What an amazing project! . . . All  
best wishes to all of you, and again, congratulations on a excellent work."_  
(Mark Leier, author of **Bakunin: The Creative Passion** )

_"monumental and essential FAQ dedicated to anarchism"_  
(Norman Baillargeon, **L'order moins le pouvoir: Histoire et  
actualité de l'anarchisme**)

_"The Anarchist FAQ should be one of the first stops for anyone  
studying anarchism. It's an extensive compilation of material,  
painstakingly indexed, of anarchist history, theory and practice.  
Just tracing the tantalising block quotes to their original sources,  
via the amazing bibliography--which alone is worth the price of the  
book--will take you a long way toward an education on any of the  
subject headings. On a personal note, I benefited greatly from  
stumbling across the FAQ near the beginning of my own journey  
into anarchism." _ (Kevin Carson author of **Studies in  
Mutualist Political Economy**)

_""Found it very detailed and informative and I'm sure it will prove to be an  
excellent reference book for those interested in the subject and for those  
who wish to defend anarchism."_ (John Couzin, anarchist from Glasgow)

  

[‹ An Anarchist FAQ: Introduction to Volume 2](vol2intro.md "Go to previous
page") [up](intro.md "Go to parent page") [An Anarchist FAQ Webpage Contacts
›](contact.md "Go to next page")
